@@ -3,28 +3,17 @@
 
 import os
 import time
-from typing import Dict, Optional, List
+from typing import Dict, List, Optional
 
 import numpy as np
 from tqdm import tqdm
 
+from sahi.postprocess.combine import NMSPostprocess, PostprocessPredictions, UnionMergePostprocess
 from sahi.prediction import ObjectPrediction, PredictionResult
-from sahi.postprocess.combine import UnionMergePostprocess, PostprocessPredictions, NMSPostprocess
 from sahi.slicing import slice_image
 from sahi.utils.coco import Coco, CocoImage
-from sahi.utils.cv import (
-    crop_object_predictions,
-    read_image_as_pil,
-    visualize_object_predictions,
-)
-from sahi.utils.file import (
-    Path,
-    import_class,
-    increment_path,
-    list_files,
-    save_json,
-    save_pickle,
-)
+from sahi.utils.cv import crop_object_predictions, read_image_as_pil, visualize_object_predictions
+from sahi.utils.file import Path, import_class, increment_path, list_files, save_json, save_pickle
 
 MODEL_TYPE_TO_MODEL_CLASS_NAME = {
     "mmdet": "MmdetDetectionModel",
@@ -654,9 +643,10 @@ def predict_fiftyone(
             0: no print
             1: print slice/prediction durations, number of slices, model loading/file exporting durations
     """
-    from sahi.utils.fiftyone import create_fiftyone_dataset_from_coco_file
     import fiftyone as fo
 
+    from sahi.utils.fiftyone import create_fiftyone_dataset_from_coco_file
+
     # assert prediction type
     assert (
         no_standard_prediction and no_sliced_prediction
